==> payara-embedded-all-4.1.1.171-sources.jar: org/glassfish/admin/rest/results/Result.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2009-2011 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package org.glassfish.admin.rest.results;

/**
 * Response information object. Information used by provider
 * to generate the appropriate output.
 *
 * @author Rajeshwar Patil
 */
public class Result {

    public Result() {
        __isError = false;
        __errorMessage = null;
    }

    /**
     * Returns name of the resource, this result object is for.
     */
    public String getName() {
        return __name;
    }

    /**
     * Returns true in case of error. Enables provider to generate
     * error message or otherwise.
     */
    public boolean isError() {
        return __isError;
    }

    /**
     * Returns error message in case of an error.
     */
    public String getErrorMessage() {
        return __errorMessage;
    }

    /**
     * Sets status (error or success) of the response
     */
    public void setIsError(boolean isError) {
        __isError = isError;
    }

    /**
     * Sets error message of the response
     */
    public void setErrorMessage(String errorMessage) {
        __errorMessage =  errorMessage;
    }

    boolean __isError;
    String __errorMessage;
    String __name;
}

==> payara-embedded-all-5.193.1-sources.jar: org/glassfish/admin/rest/results/Result.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2009-2011 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package org.glassfish.admin.rest.results;

/**
 * Response information object. Information used by provider
 * to generate the appropriate output.
 *
 * @author Rajeshwar Patil
 */
public class Result {

    public Result() {
        isError = false;
        errorMessage = null;
    }

    /**
     * Returns name of the resource, this result object is for.
     */
    public String getName() {
        return name;
    }

    /**
     * Returns true in case of error. Enables provider to generate
     * error message or otherwise.
     */
    public boolean isError() {
        return isError;
    }

    /**
     * Returns error message in case of an error.
     */
    public String getErrorMessage() {
        return errorMessage;
    }

    /**
     * Sets status (error or success) of the response
     */
    public void setIsError(boolean isError) {
        this.isError = isError;
    }

    /**
     * Sets error message of the response
     */
    public void setErrorMessage(String errorMessage) {
        this.errorMessage =  errorMessage;
    }

    boolean isError;
    String errorMessage;
    String name;
}
